#
# spec file for package matomo
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

%define apxs %{_sbindir}/apxs2
%define ap_sysconfdir %(%{apxs} -q SYSCONFDIR)
%define ap_serverroot %(%{apxs} -q PREFIX)

%if 0%{?suse_version}
%define ap_usr wwwrun
%define ap_grp www
%else
%define ap_usr nobody
%define ap_grp nogroup
%endif

Name:           matomo
Version:        3.9.1
Release:        lp152.2.2
Summary:        Web analytics platform
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Web/Utilities
Url:            http://matomo.org/
Source0:        http://builds.matomo.org/%{name}-%{version}.tar.gz
Source2:        %{name}.conf
Source3:        %{name}.logrotate
Source4:        %{name}-README.SUSE
Source10:       %{name}-archive.cron
Source11:       %{name}-archive.service
Source12:       %{name}-archive.timer
Source99:       %{name}.rpmlintrc
BuildArch:      noarch
%if 0%{?suse_version} >= 1500
Requires(pre):  user(%ap_usr)
Requires(pre):  group(%ap_grp)
%else
Requires(pre):  aaa_base
%endif
BuildRequires:  apache2-devel
BuildRequires:  cron
BuildRequires:  fdupes
BuildRequires:  logrotate
BuildRequires:  mariadb
#BuildRequires:  php-json
#BuildRequires:  php-mbstring
#BuildRequires:  php-pdo
BuildRequires:  systemd
BuildRequires:  unzip
Requires:       apache2
Requires:       cron
Requires:       logrotate
Requires:       mariadb
Requires:       mod_php_any >= 5.5.9
Requires:       php-curl
Requires:       php-gd
Requires:       php-json
Requires:       php-mbstring
Requires:       php-mysql
Requires:       php-pdo
%{?systemd_requires}
Recommends:     php-geoip
Recommends:     apache2-mod_geoip

Conflicts:      piwik

%description
Matomo, formerly Piwik, is a web analytics platform that gives
insights into a website's visitors and marketing campaigns, so the
strategy and online experience of visitors may be optimized.

%prep
%setup -q -n matomo
install -m644 %{SOURCE4} README.SUSE
# remove unwanted files
find . -type f "(" -name .htaccess -o -name .travis.sh ")" -delete
#find . -name ".git*" -exec rm -Rf "{}" "+"
find . -type f "(" -name "*.c" -o -name "*.h" ")" -delete
# env-script-interpreter
find . -type f -exec sed -i -e 's|\/usr\/bin\/env php|\/usr\/bin\/php|g' {} +

%build
# nothing to build

%install
# make directories
install -d -m0755 %{buildroot}/%{ap_serverroot}/%{name}
install -d -m0755 %{buildroot}/%{_sysconfdir}/%{name}
install -d -m0755 %{buildroot}/%{_defaultdocdir}/%{name}
# copy src from build to buildroot
mv *SUSE %{buildroot}/%{_defaultdocdir}/%{name}
mv LEGALNOTICE %{buildroot}/%{_defaultdocdir}/%{name}
mv LICENSE %{buildroot}/%{_defaultdocdir}/%{name}
mv "misc/How to install Matomo.html" %{buildroot}/%{_defaultdocdir}/%{name}
mv *md %{buildroot}/%{_defaultdocdir}/%{name}
cp -dR * %{buildroot}/%{ap_serverroot}/%{name}
# install matomo.conf to apache conf.d
install -D -m0640 %{SOURCE2} %{buildroot}/%{ap_sysconfdir}/conf.d/%{name}.conf
# install logrotate
install -D -m0644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/logrotate.d/%{name}
# move config to etc/matomo and make symlink
mv %{buildroot}/%{ap_serverroot}/%{name}/config/* \
   %{buildroot}/%{_sysconfdir}/%{name}
rm -d %{buildroot}/%{ap_serverroot}/%{name}/config
ln -s %{_sysconfdir}/%{name} %{buildroot}/%{ap_serverroot}/%{name}/config
# install cronscript and systemd-timer
install -d -m 0755 %{buildroot}/%{_sysconfdir}/cron.d
install -d -m 0755 %{buildroot}/var/log/%{name}
install -D -m 0644 %{SOURCE10} %{buildroot}/%{_sysconfdir}/cron.d/%{name}-archive
install -D -m 0644 %{SOURCE11} %{buildroot}%{_unitdir}/%{name}-archive.service
install -D -m 0644 %{SOURCE12} %{buildroot}%{_unitdir}/%{name}-archive.timer
sed -i -e 's|@ap_serverroot@|%{ap_serverroot}|g' %{buildroot}%{_sysconfdir}/cron.d/%{name}-archive
sed -i -e 's|@ap_serverroot@|%{ap_serverroot}|g' %{buildroot}%{_unitdir}/%{name}-archive.service

%fdupes %{buildroot}/%{_prefix}
%fdupes %{buildroot}/srv

%pre
%service_add_pre matomo-archive.timer matomo-archive.service

%post
chown -R %{ap_usr}:%{ap_grp} %{ap_serverroot}/%{name}
%service_add_post matomo-archive.timer matomo-archive.service apache2.service
# Update matomo if this is an upgrade $1 == 2
echo "matomo: Update matomo:core..."
if [ $1 -gt 1 ]; then
  su wwwrun -s /bin/sh -c "%{_bindir}/php %{ap_serverroot}/%{name}/console config:set 'Tracker.record_statistics="0"'" || :
  su wwwrun -s /bin/sh -c "%{_bindir}/php %{ap_serverroot}/%{name}/console config:set 'General.maintenance_mode="1"'" || :
  su wwwrun -s /bin/sh -c "%{_bindir}/php %{ap_serverroot}/%{name}/console core:update --yes" || :
  su wwwrun -s /bin/sh -c "%{_bindir}/php %{ap_serverroot}/%{name}/console config:set 'General.maintenance_mode="0"'" || :
  su wwwrun -s /bin/sh -c "%{_bindir}/php %{ap_serverroot}/%{name}/console config:set 'Tracker.record_statistics="1"'" || :
  :
fi

%preun
%service_del_preun matomo-archive.timer matomo-archive.service

%postun
%service_del_postun matomo-archive.timer matomo-archive.service apache2.service

%files
%defattr(-,root,root,-)
#%%doc README.SUSE CHANGELOG.md CONTRIBUTING.md LEGALNOTICE README.md SECURITY.md
%dir %{_defaultdocdir}/%{name}
%{_defaultdocdir}/%{name}/*
%config(noreplace) %{ap_sysconfdir}/conf.d/%{name}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/cron.d/%{name}-archive
%{_unitdir}/%{name}-archive.service
%{_unitdir}/%{name}-archive.timer
%dir %attr(0750,%{ap_usr},%{ap_grp}) %{_sysconfdir}/%{name}
%dir %attr(0750,%{ap_usr},%{ap_grp}) %{_sysconfdir}/%{name}/environment
%defattr(640,%{ap_usr},%{ap_grp},750)
%dir %{ap_serverroot}/%{name}
%dir /var/log/%{name}
%config(noreplace)  %attr(600,%{ap_usr},%{ap_grp}) %{_sysconfdir}/%{name}/*php
%{_sysconfdir}/%{name}/environment/*php
%attr(0770,%{ap_usr},%{ap_grp}) %{ap_serverroot}/%{name}/console
%attr(0770,%{ap_usr},%{ap_grp}) %{ap_serverroot}/%{name}/misc/cron/archive.sh
%attr(0770,%{ap_usr},%{ap_grp}) %{ap_serverroot}/%{name}/misc/log-analytics/import_logs.py
%attr(0770,%{ap_usr},%{ap_grp}) %{ap_serverroot}/%{name}/misc/composer/clean-xhprof.sh
%attr(0770,%{ap_usr},%{ap_grp}) %{ap_serverroot}/%{name}/misc/composer/build-xhprof.sh
%attr(0770,%{ap_usr},%{ap_grp}) %{ap_serverroot}/%{name}/vendor/leafo/lessphp/package.sh
%attr(0770,%{ap_usr},%{ap_grp}) %{ap_serverroot}/%{name}/vendor/leafo/lessphp/lessify
%attr(0770,%{ap_usr},%{ap_grp}) %{ap_serverroot}/%{name}/vendor/leafo/lessphp/plessc
%attr(0770,%{ap_usr},%{ap_grp}) %{ap_serverroot}/%{name}/vendor/pear/archive_tar/sync-php4
%attr(0770,%{ap_usr},%{ap_grp}) %{ap_serverroot}/%{name}/vendor/szymach/c-pchart/coverage.sh
%attr(0770,%{ap_usr},%{ap_grp}) %{ap_serverroot}/%{name}/vendor/tecnickcom/tcpdf/tools/tcpdf_addfont.php
%{ap_serverroot}/%{name}/*

%changelog
* Fri Mar 22 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- Update to 3.9.1
  * This release addresses a couple of issues and errors discovered
    in Matomo 3.9.0. 4 tickets have been closed by 2 contributors.
  - #14229 Notice – unserialize(): Error at offset 0 of 53988
    bytes
  - #14226 open_basedir restriction AND Support multiple plugin
    paths [by @sgiehl]
  - #14227 One-click upgrade sometimes fails with errors such as
    “Call to undefined method
    Piwik\Plugin\Manager::getPluginDirectory() ”
    (fails only once, works after a refresh)
  - #14240 Do not send password changed email for automated use
    cases. [by @diosmosis, @sgiehl]
* Wed Mar 20 2019 ecsos@opensuse.org
- Update to 3.9.0
  * Breaking Changes
  - Referrers.getKeywordsForPageUrl and
    Referrers.getKeywordsForPageTitle APIs have been deprecated
    and will be removed in Matomo 4.0.0
  - By default, Matomo application logs will now be logged in
    tmp/logs/matomo.log instead of tmp/logs/piwik.log. This log
    file path can be edited in your config/config.ini.php in
    the INI setting logger_file_path.
    Not relevant for this suse package.
  * New Features
  - It is now possible to locate plugins in a custom directory
    by setting an environment variable MATOMO_PLUGIN_DIRS or a
    ['MATOMO_PLUGIN_DIRS'] variable in /bootstrap.php.
  - It is now possible to use monolog's FingersCrossedHandler
    which buffers all logs and logs all of them in case of
    warning or error.
  * New APIs
  - New API methods Piwik\Plugin\Manager::getPluginsDirectories()
    and Piwik\Plugin\Manager::getPluginDirectory() have been
    added as it is now possible to locate Matomo plugins in
    different directories and it should be no longer assumed
    a plugin is located in the /plugins directory.
  - A new tracker method disableQueueRequest has been added to
    disable queued requests which may be useful when logs are
    imported.
  - The event LanguageManager.getAvailableLanguages has been
    deprecated. Use LanguagesManager.getAvailableLanguages
    instead.
* Tue Jan 29 2019 ecsos@opensuse.org
- Update to 3.8.1
  This release addresses a few minor issues discovered in 3.8.0 and
  a few improvements were also added.
  Detail changelog see: https://matomo.org/changelog/matomo-3-8-1/
* Thu Jan 24 2019 ecsos@opensuse.org
- Fix paths in cron and service file.
* Tue Jan 22 2019 ecsos@opensuse.org
- Update to 3.8.0
  This is an update and security release.
  Detail changelog see: https://matomo.org/changelog/matomo-3-8-0/
* Tue Nov 27 2018 ecsos@opensuse.org
- Remove %%config from service files. Changes must not do in system
  location, user must do this changes in /etc/systemd/system.
* Thu Nov 22 2018 Jan Engelhardt <jengelh@inai.de>
- Join %%service_* calls, find calls, everything that iterates
  (except for fdupes, where /usr files naturally should be
  separated from /srv).
- Require user/group package.
* Tue Nov 20 2018 ecsos@opensuse.org
- Update to 3.7.0
  This is an update and security release.
  Detail changelog see: https://matomo.org/changelog/matomo-3-7-0/
* Sat Nov 17 2018 ecsos@opensuse.org
- Remove verification for systemd
- Add systemd-timer for auto archiving of reports.
  Now you can use cron or systemd.timer.
- Add core:update during update of package
- Add logrotate
- Add rpmlintrc
- Upgrade README.SUSE
* Fri Oct 19 2018 ecsos@opensuse.org
- update to 3.6.1
  [#] New APIs
  * Added new event `Access.modifyUserAccess` which lets plugins
    modify current user's access levels/permissions.
  * Added new event `CustomMatomoJs.manipulateJsTracker` which
    lets plugins modify the JavaScript tracker.
  [#] New Developer Features
  * Logging to a file can now be easily enabled during tests.
    A new `[tests] enable_logging` INI option has been added,
    which you can set to `1` to enable logging for all tests.
    The `tests:run` and `tests:run-ui` commands now both have an
    `--enable-logging` option to enable logging for a specific
    run.
* Thu Aug 30 2018 ecsos@opensuse.org
- update to 3.6.0
  This a update and security release.
  [#] New Features
  * A new role has introduced called "write" which has less
    permissions than an admin but more than a view only user
    (see FAQ).
  * Custom currencies can now be added using the currencies[]
    configuration key.
  * A new segment eventValue lets you select all users who
    tracked a custom event with a given value or range of values.
  [#] New config.ini.php settings
  * archiving_profile = 0, if set to 1, core:archive profiling
    information will be recorded in a log file. the log file is
    determined by the archive_profiling_log option.
  * archive_profiling_log =, if set to an absolute path,
    core:archive profiling information will be logged
    to specified file.
  * enable_internet_features=0 will now fully disable Internet
    access by preventing all outgoing connections. Note: changing
    this setting is not recommended for security, because you
    will lose the easy auto-update and email notifications.
  * login_whitelist_ip[] now supports hostnames so you can
    whitelist your IP addresses and/or Hostnames and keep your
    Matomo secure.
  [#] Updated commands
  * New parameter --concurrent-archivers to define the number of
    maximum archivers to run in parallel on this server.
    Useful to prevent archiving processes piling up and
    ultimately failing.
  [#] New APIs
  * Added new event API.addGlossaryItems which lets you add items
    to the glossary.
  * Added new event Tracker.detectReferrerSocialNetwork which
    lets you add custom social network detections
  * Added new event Report.unsubscribe which is triggered
    whenever someone unsubscribe from a report
  * Added new API method UsersManager.getAvailableRoles to fetch
    a list of all available roles that can be granted to a user.
  * Added new API method UsersManager.getAvailableCapabilities to
    fetch a list of all available capabilities that can be
    granted to a user.
  * Added new API method UsersManager.addCapabilities to grant
    one or multiple capabilities to a user.
  * Added new API method UsersManager.removeCapabilities to
    remove one or multiple capabilities from a user.
  * The API method UsersManager.setUserAccess now accepts an
    array to pass a role and multiple capabilities at once.
  * Plugin classes can overwrite the method
    requiresInternetConnection to define if they should be
    automatically unloaded if no internet connection is available
    (enable_internet_features = 0)
  * Added two new methods to the JS tracker: removeEcommerceItem
    and clearEcommerceCart to allow better control over what is
    in the ecommerce cart.
  * Tracking API requests now include &consent=1 in the Tracking
    API URL When consent has been given by a user.
  [#] Breaking Changes
  * Changed some menu items to use translation keys instead
    (see PR #12885).
  * The methods assertResponseCode() and assertHttpResponseText()
    in Piwik\Tests\Framework\TestCase\SystemTestCase have been
    deprecated and will be removed in Matomo 4.0. Please use
    Piwik\Http instead.
  * The classes PHPUnit\Framework\Constraint\HttpResponseText
    and PHPUnit\Framework\Constraint\ResponseCode have been
    deprecated and will be removed in Matomo 4.0. Please use
    Piwik\Http instead.
  * Creating links through the Proxy has been deprecated.
    Use rel="nofollow" instead.
  * The console option --piwik-domain has been deprecated and
    will be removed in Matomo 4.0. Use --matomo-domain instead
  * Social networks are now detected as new referrer type (ID=7),
    which allows improved reports and better segmentation
  * New settings form field UI component "Field Array" that lets
    users enter multiple values for one setting as a flat array
* Sat May 26 2018 ecsos@opensuse.org
- update to 3.5.1
  [#] New APIs
  * Added new method Piwik\API\Request::isRootRequestApiRequest()
    to detect if the root request is an API request.
* Wed May  9 2018 ecsos@opensuse.org
- update to 3.5.0
  [#] Breaking Changes
  * Flattened action url reports now always include a leading `/`
    and will no longer include the `default_action_name`.
    e.g. `path/to/index` will now be `/path/to/`.
    This might affect configured custom alerts, as this plugin
    uses the flattened url reports for comparison.
  [#] New APIs
  * New JavaScript tracker functions to [ask for consent]
    (https://developer.matomo.org/guides/tracking-javascript-
    guide#asking-for-consent): `requireConsent`,
    `rememberConsentGiven`, `setConsentGiven`,
    `forgetConsentGiven`.
  * New events `PrivacyManager.deleteLogsOlderThan`,
    `PrivacyManager.exportDataSubjects` and
    `PrivacyManager.deleteDataSubjects` to enable plugins to be
    GDPR compliant.
  * New event `AssetManager.addStylesheets` to add additional
    less styles which are not located in a file.
  * New event `Archiving.getIdSitesToMarkArchivesAsInvalidated`
    that lets plugins customize the behaviour of report
    invalidations.
  * Reports and visualizations can now disable the 'all' rows
    limit selector:
    `$view->config->disable_all_rows_filter_limit`.
  * New settings form field UI component "Multi Tuple" that
    lets users enter multiple values for one setting
  Detail changelog see: https://matomo.org/changelog/matomo-3-5-0/
* Sun Apr  8 2018 ecsos@opensuse.org
- update to 3.4.0
  - `piwik` font is deprecated and will be removed in Matomo 4.0.
    Please use new `matomo` font instead
  - New APIs
  See https://matomo.org/changelog/matomo-3-4-0/
* Thu Feb  8 2018 jengelh@inai.de
- Ensure neutrality of description.
- Fix unknown RPM category group.
- Replace old $RPM_ variables with macros.
- Avoid %%__-type macro indirections.
- Do not let fdupes cross partitions.
* Sat Jan 13 2018 ecsos@opensuse.org
- Branch package from piwik,
  because piwik renamed to matomo.
- update to 3.3.0
  See https://matomo.org/changelog/matomo-3-3-0/
* Thu Dec  7 2017 ecsos@opensuse.org
- update to 3.2.1
  see https://piwik.org/changelog/piwik-3-2-1/
* Fri Oct 13 2017 ecsos@opensuse.org
- update to 3.2.0
  see https://piwik.org/changelog/piwik-3-2-0/
* Thu Sep 21 2017 ecsos@opensuse.org
- update to 3.1.1
  see https://piwik.org/changelog/piwik-3-1-1/
* Tue Sep 12 2017 ecsos@opensuse.org
- update to 3.1.0
  This release is rated important, two XSS issues have bin fixed.
  Also 120 tickets closed.
  see https://piwik.org/changelog/piwik-3-1-0/
* Tue Aug 15 2017 ecsos@opensuse.org
- fix spec to use php7 too
* Tue Aug 15 2017 ecsos@opensuse.org
- fix errors in piwik.conf
* Thu May 18 2017 ecsos@opensuse.org
- update to 3.0.4
  see https://piwik.org/changelog/piwik-3-0-4/
* Wed Apr  5 2017 ecsos@opensuse.org
- update to 3.0.3
  see https://piwik.org/changelog/piwik-3-0-3/
* Fri Mar  3 2017 ecsos@opensuse.org
- update to 3.0.2
  see https://piwik.org/changelog/piwik-3-0-2/
* Tue Jan 10 2017 ecsos@opensuse.org
- update to 3.0.1
  see https://piwik.org/changelog/piwik-3-0-1/
* Tue Dec 20 2016 ecsos@opensuse.org
- update to 3.0.0
  see https://piwik.org/changelog/piwik-3-0-0/
* Tue Nov 15 2016 ecsos@opensuse.org
- update to 2.17.1
  see https://piwik.org/changelog/piwik-2-17-1/
* Fri Oct 28 2016 ecsos@opensuse.org
- update to 2.17.0
  see https://piwik.org/changelog/piwik-2-17-0/
* Wed Oct  5 2016 ecsos@opensuse.org
- update to 2.16.5
  see https://piwik.org/changelog/piwik-2-16-5/
* Tue Oct  4 2016 ecsos@opensuse.org
- update to 2.16.4
  see https://piwik.org/changelog/piwik-2-16-4/
* Tue Oct  4 2016 ecsos@opensuse.org
- update to 2.16.3
  see https://piwik.org/changelog/piwik-2-16-3/
  - This is a security release
* Wed Aug  3 2016 ecsos@opensuse.org
- update to 2.16.2
  see https://piwik.org/changelog/piwik-2-16-2/
  - This is a security release
* Tue Apr 12 2016 ecsos@opensuse.org
- update to 2.16.1
  see http://piwik.org/changelog/piwik-2-16-1/
  - This is a security release
- Drop piwik-manifest_unneeded_files.patch: It's now in upstream
* Thu Feb  4 2016 ecsos@opensuse.org
- update to 2.16.0
  see http://piwik.org/changelog/piwik-2-16-0/
* Fri Oct 23 2015 ecsos@opensuse.org
- update to 2.15.0
  see http://piwik.org/changelog/piwik-2-15-0/
- insert attention mark for php caches in README.SUSE
- activate and update manifest patch
* Thu Aug  6 2015 ecsos@opensuse.org
- update to 2.14.3
  - #8439 Install of 2.14.2 blocked by permissions check on
    piwik/config path [by @mnapoli]
  - #8431 Overlay improvements [by @sgiehl, @tsteur]
  - #8352 In Page Overlay sidebar, add icon to let me
    “Open segmented visitor log” [by @sgiehl]
  - #8403 Improve design of Trusted Piwik Hostname setting
    [by @barbushin, @tsteur]
  - #7835 Rename “Widgets & Dashboard” selector or change the
    selector [by @tsteur]
  - #8293 Piwik errors logged in server error log should not have
    HTML [by @mnapoli]
  - #8252 New config entry to set email name in email FROM field
    [by @tsteur]
  - #8472 Fix bug in notification angular directive, do not use
    data-binding for noclear attribute… [by @diosmosis]
  - #8285 UserCountryMap plugin shows wrong options in countries
    select [by @mnapoli]
  - #8432 [automatic translation update] Updated 195 strings in
    32 languages (sk, ar, de, ja, nl, nb, sv, be, bg, ca, cs, da,
    el, es, fa, fi, fr, hi, hu, id, it, ko, pl, pt, ro, ru, sq, sr,
    th, tl, uk, vi) [by @sgiehl]
  - #8474 [automatic translation update] Updated 254 strings in
    37 languages (gl, nb, cs, it, sk, de, el, fr, lt, ar, bg, ca,
    da, es, et, fa, fi, he, hi, hr, id, ja, ko, nl, nn, pl, ro, ru,
    sl, sq, sr, sv, ta, th, tl, tr, vi) [by @sgiehl]
* Wed Jul 29 2015 ecsos@opensuse.org
- update to 2.14.2
  - #8304 Column not found: 1054 Unknown column
    ‘log_visit.location_browser_lang’ in ‘field list'” [by @tsteur]
  - #8365 renderer format is not valid – fatal php error after
    2.14.0
  - #8316 URL parameter for core:archive console command is ignored
    [by @diosmosis, @mattab]
  - #8307 Limit notifications of not authenticated sessions
    [by @tsteur]
  - #8370 Can’t update GrabGravatar plugin [by @tsteur]
  - #8346 node.className.split is not a function on tracking click
    on/near SVG element [by @dandv, @tsteur]
  - #8294 CLI plugin generator doesn’t intercept plugin description
    [by @tsteur]
  - #8257 Site Search report does not display tooltips with metrics
    documentation
  - #7768 Browser info tooltip doesn’t hide
  - #8411 Add System check that checks that shell_exec function is
    enabled [by @mattab]
  - #8407 The string General_Cancel was not loaded in javascript
    [by @tsteur]
  - #8400 Fix emails validation with unknown TLD
    [by @barbushin, @mnapoli]
  - #8379 Travis system extraction part 1 [by @diosmosis]
  - #8374 Tweaks to .travis.yml generator [by @diosmosis]
  - #8376 [automatic translation update] Updated 661 strings in
    8 languages (nl, sv, de, es, ja, lt, pl, nb) [by @sgiehl]
* Sat Jun 13 2015 ecsos@opensuse.org
- initial version 2.13.1
